@@ -8,7 +8,9 @@ from redis_sessions import settings
 
 
 # Avoid new redis connection on each request
-if settings.SESSION_REDIS_UNIX_DOMAIN_SOCKET_PATH is None:
+if not settings.SESSION_REDIS_URL is None:
+    redis_server = redis.StrictRedis.from_url(settings.SESSION_REDIS_URL)
+elif settings.SESSION_REDIS_UNIX_DOMAIN_SOCKET_PATH is None:
     redis_server = redis.StrictRedis(
         host=settings.SESSION_REDIS_HOST,
         port=settings.SESSION_REDIS_PORT,
